@@ -8,8 +8,14 @@ load_dotenv()  # take environment variables from .env.
 if not 'AWS_PROFILE' in os.environ:
     raise Exception('Missing AWS_PROFILE environment variable!')
 
+if not 'PYTHONHASHSEED' in os.environ:
+    raise Exception('PYTHONHASHSEED must be set to 0 in the environment!')
+else:
+    if os.environ['PYTHONHASHSEED']!='0':
+        raise Exception('PYTHONHASHSEED must be set to 0 in the environment!')
+
 if not 'DATABASE_FOLDER' in os.environ:    
-    os.environ['DATABASE_FOLDER'] = os.path.expanduser("~")+'\DB' 
+    os.environ['DATABASE_FOLDER'] = os.path.expanduser("~")+'/db'
 
 if not 'S3_BUCKET' in os.environ:    
     os.environ['S3_BUCKET'] = 's3://deepportfolio'
