@@ -8,19 +8,18 @@ import pandas as pd
 from pythonjsonlogger.jsonlogger import JsonFormatter
 import boto3
 
-from importlib.metadata import version
-
-import SharedData.Defaults as Defaults 
-from SharedData.SharedDataAWSKinesis import KinesisLogStreamHandler
 
+from SharedData.AWSKinesis import KinesisLogStreamHandler
 
 class Logger:
 
     log = None
-    user = None
+    user = 'guest'
+    source = 'unknown'
 
-    def __init__(self, source, user=None):
-        if Logger.log is None:                                
+    @staticmethod
+    def connect(source,user=None):
+        if Logger.log is None:
             if 'SOURCE_FOLDER' in os.environ:
                 try:
                     commompath = os.path.commonpath([source,os.environ['SOURCE_FOLDER']])
@@ -34,21 +33,19 @@ class Logger:
                 except:
                     pass
             
-            source = source.replace('venv\\lib\\site-packages\\','')
+            finds = 'site-packages'
+            if finds in source:
+                cutid = source.find(finds) + len(finds) + 1
+                source = source[cutid:]            
             source = source.replace('Windows\\system32\\','')
-
-            if not user is None:                
-                Logger.user = user
-            else:
-                user = 'guest'
-                Logger.user = 'guest'
-            
-            
             source = source.lstrip('src').lstrip('\\src')
             source = source.lstrip('\\').lstrip('/')        
             source = source.replace('.py','')
-            self.source = source
-
+            Logger.source = source
+            
+            if not user is None:                
+                Logger.user = user
+                        
             path = Path(os.environ['DATABASE_FOLDER'])
             path = path / 'Logs'
             path = path / datetime.now().strftime('%Y%m%d')
@@ -67,8 +64,8 @@ class Logger:
                 loglevel = logging.INFO
 
             # Create Logger
-            self.log = logging.getLogger(source)
-            self.log.setLevel(logging.DEBUG)    
+            Logger.log = logging.getLogger(source)
+            Logger.log.setLevel(logging.DEBUG)    
             formatter = logging.Formatter(os.environ['USERNAME']+'@'+os.environ['COMPUTERNAME'] + 
                 ';%(asctime)s;%(name)s;%(levelname)s;%(message)s',\
                 datefmt='%Y-%m-%dT%H:%M:%S%z')
@@ -76,12 +73,12 @@ class Logger:
             handler = logging.StreamHandler()
             handler.setLevel(loglevel)    
             handler.setFormatter(formatter)
-            self.log.addHandler(handler)
-            #log file        
-            fhandler = logging.FileHandler(os.environ['LOG_PATH'], mode='a')
-            fhandler.setLevel(loglevel)    
-            fhandler.setFormatter(formatter)
-            self.log.addHandler(fhandler)
+            Logger.log.addHandler(handler)
+            # #log file        
+            # fhandler = logging.FileHandler(os.environ['LOG_PATH'], mode='a')
+            # fhandler.setLevel(loglevel)    
+            # fhandler.setFormatter(formatter)
+            # Logger.log.addHandler(fhandler)
             #log to aws kinesis
             kinesishandler = KinesisLogStreamHandler(user=Logger.user)
             kinesishandler.setLevel(logging.DEBUG)
@@ -89,15 +86,10 @@ class Logger:
                 ';%(asctime)s;%(name)s;%(levelname)s;%(message)s',\
                 datefmt='%Y-%m-%dT%H:%M:%S%z')
             kinesishandler.setFormatter(jsonformatter)
-            self.log.addHandler(kinesishandler)
-            #assign static variable log to be used by modules
-            Logger.log = self.log
-            try:
-                Logger.log.debug('Logger initialized shareddata user %s version %s!' % \
-                    (Logger.user,version('SharedData')))
-            except:
-                Logger.log.debug('Logger initialized shareddata!')
+            Logger.log.addHandler(kinesishandler)            
+            
         
+    @staticmethod
     def readLogs(self):    
         logsdir = Path(os.environ['LOG_PATH']).parents[0]
         lenlogsdir = len(str(logsdir))
