@@ -1,9 +1,11 @@
 import time
 import numpy as np
 
+
+from SharedData.SharedData import SharedData
+shdata = SharedData(__file__,user='worker')
 from SharedData.Logger import Logger
-logger = Logger(__file__,user='worker')
-from SharedData.SharedDataAWSKinesis import KinesisLogStreamConsumer
+from SharedData.AWSKinesis import KinesisLogStreamConsumer
 
 SLEEP_TIME = 2
 
