@@ -4,7 +4,10 @@
 import multiprocessing
 from concurrent.futures import ProcessPoolExecutor
 from concurrent.futures import ThreadPoolExecutor
-
+from cffi import FFI
+from tqdm import tqdm
+import time
+from threading import Thread
 
 # USAGE EXAMPLE:
 # io_bound(thread_func, iterator, args)
@@ -31,30 +34,17 @@ from concurrent.futures import ThreadPoolExecutor
 #     idx = (calendars[cal]>=start) & ((calendars[cal]<=end))
 #     return [np.count_nonzero(idx)]
 
-# return the contents of many files
-def io_bound_process(thread_func, proc_iterator, args):
-    results = []
-    # create a thread pool
-    nproc_iterator = len(proc_iterator)
-    if nproc_iterator>0:
-        with ThreadPoolExecutor(nproc_iterator) as exe:
-            # load files
-            futures = [exe.submit(thread_func, iteration, args) for iteration in proc_iterator]
-            # collect data
-            for future in futures:
-                res = future.result()
-                results = [*results, *res]
-        
-    return results
- 
+
 # load all files in a directory into memory
-def io_bound(thread_func, iterator, args):
-    results = []
+def io_bound(thread_func, iterator, args, maxproc=None, maxthreads=10):
+    results = []    
     # determine chunksize
     niterator = len(iterator)
     if niterator>0:
-        n_workers = multiprocessing.cpu_count() - 2      
+        n_workers = multiprocessing.cpu_count() - 2
         n_workers = min(n_workers,niterator)
+        if not maxproc is None:
+            n_workers = min(n_workers,maxproc)
         chunksize = round(niterator / n_workers)
         # create the process pool
         with ProcessPoolExecutor(n_workers) as executor:        
@@ -64,27 +54,42 @@ def io_bound(thread_func, iterator, args):
                 # select a chunk of filenames
                 proc_iterator = iterator[i:(i + chunksize)]
                 # submit the task
-                future = executor.submit(io_bound_process, thread_func, proc_iterator, args)
+                future = executor.submit(io_bound_process, thread_func, proc_iterator, args, maxthreads)
                 futures.append(future)
             # process all results
             for future in futures:
                 # open the file and load the data
                 res = future.result()
-                results = [*results, *res]
+                results = [*results, *res]                
     return results
 
-
 # return the contents of many files
-def cpu_bound_process(thread_func, proc_iterator, args):
-    return [thread_func(iteration, args) for iteration in proc_iterator]
-
-def cpu_bound(thread_func, iterator, args):
+def io_bound_process(thread_func, proc_iterator, args, maxthreads):
     results = []
+    # create a thread pool
+    nthreads = len(proc_iterator)
+    nthreads = min(nthreads,maxthreads)
+    if nthreads>0:
+        with ThreadPoolExecutor(nthreads) as exe:
+            # load files
+            futures = [exe.submit(thread_func, iteration, args) for iteration in proc_iterator]
+            # collect data
+            for future in futures:
+                res = future.result()
+                results = [*results, *res]
+        
+    return results
+ 
+
+def cpu_bound(thread_func, iterator, args, maxproc = None):
+    results = []    
     # determine chunksize
     niterator = len(iterator)
     if niterator>0:
         n_workers = multiprocessing.cpu_count() - 2    
         n_workers = min(n_workers,niterator)
+        if not maxproc is None:
+            n_workers = min(n_workers,maxproc)
         chunksize = round(niterator / n_workers)
         # create the process pool
         with ProcessPoolExecutor(n_workers) as executor:        
@@ -100,6 +105,24 @@ def cpu_bound(thread_func, iterator, args):
             for future in futures:
                 # open the file and load the data
                 res = future.result()
-                results = [*results, *res]
+                results = [*results, *res]    
     return results
 
+
+# return the contents of many files
+def cpu_bound_process(thread_func, proc_iterator, args):
+    results = []
+    for iteration in proc_iterator:
+        res = thread_func(iteration, args)
+        results = [*results, *res]              
+    return results
+
+def progressbar_thread(progress,niterations):
+    pbar = tqdm(total=niterations,desc='Running multi proc...')
+    while True:        
+        pbar.update(progress - pbar.n)
+        if progress >= niterations:
+            break
+        time.sleep(0.2)
+        
+        
\ No newline at end of file
